@@ -6,7 +6,7 @@ use VMware::API::vCloud;
 use VMware::vCloud::vApp;
 use strict;
 
-our $VERSION = 'v2.380';
+our $VERSION = 'v2.390';
 
 =head1 NAME
 
@@ -801,6 +801,40 @@ sub get_task {
   return $self->{api}->task_get($href);
 }
 
+=head3 progress_of_task($task_href)
+
+  my ($percent,$status) = $vcd->progress_of_task($task_href)
+
+Returns the approximate percentage of completion of the task as an integer
+between 1 and 101.
+
+The text status of the task is returned as well:
+
+* queued - The task has been queued for execution.
+* preRunning - The task is awaiting preprocessing or administrative action.
+* running - The task is running.
+* success - The task completed with a status of success.
+* error - The task encountered an error while running.
+* cancelled - The task was canceled by the owner or an administrator.
+* aborted - The task was aborted by an administrative action.
+
+=cut
+
+sub progress_of_task {
+  my $self = shift @_;
+  my $href = shift @_;  
+
+  my $task = $self->get_task($href);
+  my $status = $task->{status};
+ 
+  if ( $status eq 'queued' or $status eq 'preRunning' or $status eq 'running' or $status eq 'success' ) {
+    return ( $task->{Progress}->[0], $status );
+    die Dumper($task);
+  }  
+
+  return ( (defined $task->{Progress}->[0] ? $task->{Progress}->[0] : 101), $status );
+}
+
 =head3 wait_on_task($href)
 
 Given a task href, this method will query the task every second, and only
@@ -913,6 +947,20 @@ sub extensions {
   return $self->{api}->admin_extension_get();
 }
 
+=head2 list_datastores()
+
+Requires using a sysadmin account and attaching to the System org.
+
+Returns a hash(ref) of datastore information.
+
+=cut
+
+sub list_datastores {
+  my $self = shift @_;
+  my $ret = $self->{api}->datastore_list();  
+  return wantarray ? %{$ret->{DatastoreRecord}} : $ret->{DatastoreRecord};
+}
+
 =head3 list_external_networks()
 
 Returns a hash or hasref of all available external networks.
@@ -1006,7 +1054,7 @@ identifier of an object. This module implements this best practice.
 
 =head1 VERSION
 
-  Version: v2.380 (2013-04-17)
+  Version: v2.390 (2013-05-03)
 
 =head1 AUTHOR
 
